@@ -16,14 +16,15 @@
 # Converts a numeric value like 42414 into a date "2016-02-14"
 
 excel_numeric_to_date <- function(date_num, date_system = "modern") {
-  if(!is.numeric(date_num)){ stop("argument `date_num` must be of class numeric") }
+  if (!is.numeric(date_num)) {
+    stop("argument `date_num` must be of class numeric")
+  }
 
-  if(date_system == "mac pre-2011"){
-    as.Date(date_num,  origin = "1904-01-01")
-  } else if(date_system == "modern"){
+  if (date_system == "mac pre-2011") {
+    as.Date(date_num, origin = "1904-01-01")
+  } else if (date_system == "modern") {
     as.Date(date_num, origin = "1899-12-30")
   } else {
     stop("argument 'created' must be one of 'mac pre-2011' or 'modern'")
   }
 }
-
